@@ -30,7 +30,7 @@
 #include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
-#include <KStandardAction>
+#include <KStandardActions>
 #include <KXMLGUIFactory>
 
 SettingsBase::SettingsBase(SidebarMode::ApplicationMode mode, const QString &startupModule, const QStringList &startupModuleArgs, QWidget *parent)
@@ -125,7 +125,7 @@ void SettingsBase::initToolBar()
 {
     // Fill the toolbar with default actions
     // Exit is the very last action
-    quitAction = m_actionCollection->addAction(KStandardAction::Quit, QStringLiteral("quit_action"), this, &QWidget::close);
+    quitAction = m_actionCollection->addAction(KStandardActions::Quit, QStringLiteral("quit_action"), this, &QWidget::close);
 
     if (m_mode == SidebarMode::SystemSettings) {
         highlightChangesAction = m_actionCollection->addAction(QStringLiteral("highlight_changes"), this, [this] {
@@ -136,7 +136,7 @@ void SettingsBase::initToolBar()
         highlightChangesAction->setIcon(QIcon::fromTheme(QStringLiteral("draw-highlight")));
     }
 
-    reportPageSpecificBugAction = m_actionCollection->addAction(QStringLiteral("report_bug_in_current_module"), this, [=] {
+    reportPageSpecificBugAction = m_actionCollection->addAction(QStringLiteral("report_bug_in_current_module"), this, [this] {
         const QString bugReportUrlString =
             view->moduleView()->activeModuleMetadata().bugReportUrl() + QStringLiteral("&version=") + QGuiApplication::applicationVersion();
         auto job = new KIO::OpenUrlJob(QUrl(bugReportUrlString));
@@ -277,7 +277,7 @@ void SettingsBase::loadCurrentView()
         reportGeneralBugAction->setVisible(false);
     }
     auto moduleView = view->moduleView();
-    connect(moduleView, &ModuleView::moduleChanged, this, [=] {
+    connect(moduleView, &ModuleView::moduleChanged, this, [this, moduleView, reportGeneralBugAction] {
         reportPageSpecificBugAction->setVisible(!moduleView->activeModuleMetadata().bugReportUrl().isEmpty());
         if (reportGeneralBugAction) {
             reportGeneralBugAction->setVisible(!reportPageSpecificBugAction->isVisible());
